#!/usr/bin/env ruby
# Copyright (c) 2019, Aviz Networks. All rights reserved.
#
# This program and the accompanying materials are licensed and made available
# under the terms and conditions of the 3-clause BSD License that accompanies
# this distribution.
#
# The full text of the license may be found at
#
# https://opensource.org/licenses/BSD-3-Clause
#
# THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
# WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
require 'rest-client'
require 'yaml'

def form_hdr(conn)
  hdr = {}
  hdr['Accept'] = 'application/json'
  hdr['Content-type'] = 'application/json'
  return hdr
end

def form_url(conn, url)
  url = conn.getProtocol +  '://' + conn.getIpAddr + ':' + conn.getPort + url
  return url
end

# The Connect class provides a class implementation and methods for establishing node connections and
# initializations. This class presents an abstraction

class Connect

        # This function is used to initialise node paramters.
        #
        # @param params [Hash] Hash to hold the switch connection parameters
        #
        # @return None
        def initialize(params)
          @protocol = params['protocol']
          @port      = params['port']
          @ip_addr   = params['ip_addr']
          @user      = params['user']
          @password  = params['password']
          if @protocol == 'http'
            @url       = @protocol + '://' + @ip_addr + ':' + @port
          end

          # https is not supported
          # Need to get certificate from user and form ssl connection for https

          @hdr = {}
          @hdr['Accept'] = 'application/json'
          @hdr['Content-type'] = 'application/json'
        end

        # This API returns Protocol protocol for the current node connection.
        #
        # @return [String] Protocol protocol
        def getProtocol()
          return @protocol
        end

        # This API returns REST Port for the current node connection.
        #
        # @return [String] REST Port
        def getPort()
          return @port
        end

        # This API returns IP for the current node connection.
        #
        # @return [String] Node IP Address
        def getIpAddr()
          return @ip_addr
        end

        # This API returns User for the current node connection.
        #
        # @return [String] User name credentials
        def getUser()
          return @user
        end

        # This API returns Password for the current node connection.
        #
        # @return [String] Password credentials
        def getPassword()
          return @password
        end

        # This API returns Header Info for the current node connection.
        #
        # @return [String] REST Header
        def getHdr()
          return @hdr
        end
end
