#!/usr/bin/env ruby
# Copyright (c) 2019, Aviz Networks. All rights reserved.
#
# This program and the accompanying materials are licensed and made available
# under the terms and conditions of the 3-clause BSD License that accompanies
# this distribution.
#
# The full text of the license may be found at
#
# https://opensource.org/licenses/BSD-3-Clause
#
# THE PROGRAM IS DISTRIBUTED UNDER THE BSD LICENSE ON AN "AS IS" BASIS,
# WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
require 'rest-client'
require 'json'
require_relative 'connect'
require_relative 'rest_utils'

# The Devenvs class provides a class implementation and methods for getting
# device environment details. This class presents an abstraction

class Devenvs
        @devenvs_cfg  = '/api/devenvs'

        # This API gets the device environment details
        #
        # Request URL: http://IP-ADDR:REST-PORT/api/devenvs
        #
        # @param conn [Class] Connect object to the node
        #
        # @return [RestClient::Request] Rest output from SONIC in JSON format as below
        #         {
        #          "Fans": {"fan1": "rpm", "fan2": "rpm"}
        #          “Temperature”:{ },
        #          “Power”:{ “name”:””, “status”:””},
        #          “Platform”:{ “Platform Name”:””, “ONIE version”: “”, “CRC-32”:””}
        #         }
        def self.get_devenvs_data(conn)
          url = form_url(conn, @devenvs_cfg)
          hdr = form_hdr(conn)
          Rest.get(conn, url, hdr)
        end
end
